@@ -41,6 +41,7 @@ KNOWN_ATTRIBUTES = (
     'prefixes',
     'prefixlen',
     'project_id',
+    'qos_policy_id',
     constants.SHARED,
     'status',
     'subnets',
@@ -76,47 +77,69 @@ KNOWN_ACTION_STATUSES = (
 KNOWN_EXTENSIONS = (
     'address-scope',
     'agent',
+    'agent-resources-synced',
     'allowed-address-pairs',
     'auto-allocated-topology',
     'availability_zone',
     'binding',
     'data-plane-status',
+    'project-default-networks',
     'default-subnetpools',
     'dhcp_agent_scheduler',
     'dns-domain-ports',
     'dns-integration',
     'dvr',
+    'empty-string-filtering',
+    'expose-port-forwarding-in-fip',
     'ext-gw-mode',
     'external-net',
     'extra_dhcp_opt',
     'extraroute',
+    'filter-validation',
+    'fip-port-details',
     'flavors',
+    'floating-ip-port-forwarding',
+    'floatingip-autodelete-internal',
+    'floatingip-pools',
     'ip-substring-filtering',
     'l3-ha',
     'l3_agent_scheduler',
+    'l3-port-ip-change-not-allowed',
     'logging',
     'metering',
     'multi-provider',
     'net-mtu',
     'network-ip-availability',
+    'network-segment-range',
     'network_availability_zone',
     'pagination',
+    'port-resource-request',
     'port-security',
     'project-id',
     'provider',
     'qos',
+    'qos-bw-limit-direction',
+    'qos-gateway-ip',
+    'qos-rules-alias',
     'quotas',
     'rbac-policies',
+    'rbac-security-groups',
     'router',
     'router_availability_zone',
     'security-group',
+    'segment',
     'service-type',
+    'sort-key-validation',
     'sorting',
     'standard-attr-description',
     'standard-attr-revisions',
+    'standard-attr-segment',
     'standard-attr-timestamp',
     'subnet_allocation',
     'subnet_onboard',
+    'subnetpool-prefix-ops',
+    'subnet-segmentid-enforce',
+    'subnet-segmentid-writable',
     'tag',
     'trunk',
     'trunk-details',
@@ -130,6 +153,18 @@ KNOWN_EXTENSIONS = (
     'bgpvpn',  # https://git.openstack.org/cgit/openstack/networking-bgpvpn
     'bgpvpn-routes-control',
     'bgpvpn-vni',
+
+    # git.openstack.org/cgit/openstack/neutron-vpnaas
+    'vpnaas',
+    'vpn-endpoint-groups',
+    'vpn-flavors',
+
+    # http://git.openstack.org/cgit/openstack/networking-sfc:
+    'flow_classifier',
+    'sfc',
+
+    # http://git.openstack.org/cgit/openstack/neutron-interconnection:
+    'interconnection',
 )
 
 KNOWN_KEYWORDS = (
@@ -139,8 +174,12 @@ KNOWN_KEYWORDS = (
     'convert_list_to',
     'default',
     'enforce_policy',
+    'is_filter',
+    'is_sort_key',
     'is_visible',
     'primary_key',
     'required_by_policy',
     'validate',
+    'default_overrides_none',
+    'dict_populate_defaults',
 )
