@@ -117,6 +117,17 @@ def _validate_list_of_items(item_validator, data, *args, **kwargs):
             return msg
 
 
+def _validate_list_of_items_non_empty(item_validator, data, *args, **kwargs):
+    res = _validate_list_of_items(item_validator, data, *args, **kwargs)
+
+    if res is not None:
+        return res
+
+    if len(data) == 0:
+        msg = _("List should not be empty")
+        return msg
+
+
 def validate_values(data, valid_values=None, valid_values_display=None):
     """Validate that the provided 'data' is within 'valid_values'.
 
@@ -151,7 +162,7 @@ def validate_values(data, valid_values=None, valid_values_display=None):
                 return msg
         except TypeError:
                 # This is a programming error
-                msg = (_("'data' of type '%(typedata)s' and 'valid_values'"
+                msg = (_("'data' of type '%(typedata)s' and 'valid_values' "
                          "of type '%(typevalues)s' are not "
                          "compatible for comparison") %
                        {'typedata': type(data),
@@ -588,7 +599,7 @@ def validate_hostroutes(data, valid_values=None):
         msg = _verify_dict_keys(expected_keys, hostroute)
         if msg:
             return msg
-        msg = validate_subnet(hostroute['destination'])
+        msg = validate_route_cidr(hostroute['destination'])
         if msg:
             return msg
         msg = validate_ip_address(hostroute['nexthop'])
@@ -653,6 +664,30 @@ def validate_subnet(data, valid_values=None):
     return msg
 
 
+def validate_route_cidr(data, valid_values=None):
+    """Validate data is a proper CIDR string.
+
+    :param data: The data to validate.
+    :param valid_values: Not used!
+    :returns: None if data is valid CIDR. Otherwise a human
+              readable message as to why data is invalid.
+    """
+    msg = None
+    try:
+        net = netaddr.IPNetwork(validate_no_whitespace(data))
+        if '/' not in data or (net.network != net.ip):
+            msg = _("'%(data)s' is not a recognized CIDR,"
+                    " '%(cidr)s' is recommended") % {"data": data,
+                                                     "cidr": net.cidr}
+        else:
+            return
+    except Exception:
+        msg = _("'%s' is not a valid CIDR") % data
+    if msg:
+        LOG.debug(msg)
+    return msg
+
+
 def validate_subnet_or_none(data, valid_values=None):
     """Validate data is a valid subnet address string or None.
 
@@ -681,6 +716,18 @@ def validate_subnet_list(data, valid_values=None):
     return _validate_subnet_list(data, valid_values)
 
 
+def validate_subnet_list_or_none(data, key_specs=None):
+    """Validate data is a list of subnet dicts or None.
+
+    :param data: The data to validate.
+    :param key_specs: Not used!
+    :returns: None if data is None or a valid list of subnet dicts, otherwise
+        a human readable message as to why the data is invalid.
+    """
+    if data is not None:
+        return validate_subnet_list(data, key_specs)
+
+
 def validate_regex(data, valid_values=None):
     """Validate data is matched against a regex.
 
@@ -793,29 +840,51 @@ def validate_uuid_list(data, valid_values=None):
     return _validate_uuid_list(data, valid_values)
 
 
+def validate_uuid_list_non_empty(data, valid_values=None):
+    """Validate data is a non-empty list of UUID like values.
+
+    :param data: The data to validate.
+    :param valid_values: Not used!
+    :returns: None if data is a non-empty iterable that contains valid UUID
+        values, otherwise a message is returned indicating why validation
+        failed.
+    """
+    return _validate_list_of_items_non_empty(validate_uuid, data)
+
+
+def _extract_validator(key_validator):
+    # Find validator function in key validation spec
+    #
+    # TODO(salv-orlando): Structure of dict attributes should be improved
+    # to avoid iterating over items
+    for (k, v) in key_validator.items():
+        if k.startswith('type:'):
+            (validator_name, validator_params) = (k, v)
+            try:
+                return (validator_name,
+                        validators[validator_name],
+                        validator_params)
+            except KeyError:
+                raise UndefinedValidator(validator_name)
+    return None, None, None
+
+
 def _validate_dict_item(key, key_validator, data):
     # Find conversion function, if any, and apply it
     conv_func = key_validator.get('convert_to')
     if conv_func:
         data[key] = conv_func(data.get(key))
-    # Find validator function
-    # TODO(salv-orlando): Structure of dict attributes should be improved
-    # to avoid iterating over items
-    val_func = val_params = None
-    for (k, v) in key_validator.items():
-        if k.startswith('type:'):
-            # ask forgiveness, not permission
-            try:
-                val_func = validators[k]
-            except KeyError:
-                msg = _("Validator '%s' does not exist") % k
-                LOG.debug(msg)
-                return msg
-            val_params = v
-            break
-    # Process validation
-    if val_func:
-        return val_func(data.get(key), val_params)
+    try:
+        dummy_, val_func, val_params = _extract_validator(key_validator)
+        if val_func:
+            return val_func(data.get(key), val_params)
+        # NOTE(tmorin): here we silently omit to validate a key for which
+        # no type validator has been defined
+    except UndefinedValidator as e:
+        # NOTE(tmorin): Should we really return an API error on such
+        # an issue. Wouldn't InternalServer error be more natural ?
+        LOG.debug(e.message)
+        return e.message
 
 
 def validate_dict(data, key_specs=None):
@@ -1001,8 +1070,8 @@ def validate_subports(data, valid_values=None):
         if segmentation_type == 'inherit':
             return
         segmentation_id = subport.get("segmentation_id")
-        if ((not segmentation_type or segmentation_id is None)
-                and len(subport) > 1):
+        if ((not segmentation_type or segmentation_id is None) and
+                len(subport) > 1):
             msg = _("Invalid subport details '%s': missing segmentation "
                     "information. Must specify both segmentation_id and "
                     "segmentation_type") % subport
@@ -1067,13 +1136,23 @@ validators = {'type:dict': validate_dict,
               'type:uuid': validate_uuid,
               'type:uuid_or_none': validate_uuid_or_none,
               'type:uuid_list': validate_uuid_list,
+              'type:uuid_list_non_empty': validate_uuid_list_non_empty,
               'type:values': validate_values,
               'type:boolean': validate_boolean,
               'type:integer': validate_integer,
               'type:list_of_unique_strings': validate_list_of_unique_strings,
               'type:list_of_any_key_specs_or_none':
                   validate_any_key_specs_or_none,
-              'type:service_plugin_type': validate_service_plugin_type}
+              'type:service_plugin_type': validate_service_plugin_type,
+              'type:list_of_subnets_or_none': validate_subnet_list_or_none
+              }
+
+
+class UndefinedValidator(Exception):
+
+    def __init__(self, validator_name):
+        self.validator_name = validator_name
+        self.message = _("Validator '%s' does not exist") % self.validator_name
 
 
 def _to_validation_type(validation_type):
