@@ -14,6 +14,8 @@ import copy
 
 import fixtures
 import mock
+from oslo_config import cfg
+from oslo_messaging import conffixture
 
 from neutron_lib.api import attributes
 from neutron_lib.api import definitions
@@ -21,7 +23,14 @@ from neutron_lib.callbacks import manager
 from neutron_lib.callbacks import registry
 from neutron_lib.db import api as db_api
 from neutron_lib.db import model_base
+from neutron_lib.db import model_query
+from neutron_lib.db import resource_extend
 from neutron_lib.plugins import directory
+from neutron_lib import rpc
+from neutron_lib.tests.unit import fake_notifier
+
+
+CONF = cfg.CONF
 
 
 class PluginDirectoryFixture(fixtures.Fixture):
@@ -198,3 +207,82 @@ class PlacementAPIClientFixture(fixtures.Fixture):
         self._mock_post.stop()
         self._mock_put.stop()
         self._mock_delete.stop()
+
+
+class DBRetryErrorsFixture(fixtures.Fixture):
+
+    def __init__(self, **retry_kwargs):
+        self._retry_kwargs = retry_kwargs
+        self._patchers = []
+
+    def _setUp(self):
+        for k, v in self._retry_kwargs.items():
+            patcher = mock.patch.object(db_api._retry_db_errors, k, new=v)
+            patcher.start()
+            self._patchers.append(patcher)
+        self.addCleanup(self._restore)
+
+    def _restore(self):
+        for p in self._patchers:
+            p.stop()
+
+
+class DBAPIContextManagerFixture(fixtures.Fixture):
+
+    def __init__(self, mock_context_manager=mock.ANY):
+        self.cxt_manager = (mock.Mock() if mock_context_manager == mock.ANY
+                            else mock_context_manager)
+        self._backup_mgr = None
+
+    def _setUp(self):
+        self._backup_mgr = db_api._CTX_MANAGER
+        db_api._CTX_MANAGER = self.cxt_manager
+        self.addCleanup(self._restore)
+
+    def _restore(self):
+        db_api._CTX_MANAGER = self._backup_mgr
+
+
+class DBQueryHooksFixture(fixtures.Fixture):
+
+    def _setUp(self, query_hooks=None):
+        self._backup = model_query._model_query_hooks
+        model_query._model_query_hooks = query_hooks or {}
+        self.addCleanup(self._restore)
+
+    def _restore(self):
+        model_query._model_query_hooks = self._backup
+
+
+class RPCFixture(fixtures.Fixture):
+
+    def _setUp(self):
+        # don't actually start RPC listeners when testing
+        mock.patch.object(rpc.Connection, 'consume_in_threads',
+                          return_value=[]).start()
+        self.useFixture(fixtures.MonkeyPatch(
+            'oslo_messaging.Notifier', fake_notifier.FakeNotifier))
+
+        self.messaging_conf = conffixture.ConfFixture(CONF)
+        self.messaging_conf.transport_url = 'fake:/'
+        # NOTE(russellb) We want all calls to return immediately.
+        self.messaging_conf.response_timeout = 0
+        self.useFixture(self.messaging_conf)
+
+        self.addCleanup(rpc.cleanup)
+        rpc.init(CONF)
+
+
+class DBResourceExtendFixture(fixtures.Fixture):
+
+    def __init__(self, extended_functions=None):
+        self.extended_functions = extended_functions or {}
+
+    def _setUp(self):
+        self._backup = copy.deepcopy(
+            resource_extend._resource_extend_functions)
+        resource_extend._resource_extend_functions = self.extended_functions
+        self.addCleanup(self._restore)
+
+    def _restore(self):
+        resource_extend._resource_extend_functions = self._backup
