@@ -22,3 +22,7 @@ FLAVORS = "FLAVORS"
 QOS = "QOS"
 CORE = 'CORE'
 L3 = 'L3_ROUTER_NAT'
+LOG_API = "LOGGING"
+PORTFORWARDING = "PORTFORWARDING"
+FLOATINGIPPOOL = "FLOATINGIPPOOL"
+NETWORK_SEGMENT_RANGE = "NETWORK_SEGMENT_RANGE"
