@@ -138,6 +138,17 @@ class TestAttributeInfo(base.BaseTestCase):
         self.assertRaises(self._EXC_CLS, attr_inst.fill_post_defaults,
                           {'key': 'X'}, self._EXC_CLS)
 
+    def test_fill_none_overridden_by_default(self):
+        attr_info = {
+            'key': {
+                'allow_post': True,
+                'default': 42,
+                'default_overrides_none': True,
+            },
+        }
+        attr_inst = attributes.AttributeInfo(attr_info)
+        self._test_fill_default_value(attr_inst, {'key': 42}, {'key': None})
+
     def _test_convert_value(self, attr_inst, expected, res_dict):
         attr_inst.convert_values(res_dict)
         self.assertEqual(expected, res_dict)
@@ -269,3 +280,44 @@ class TestCoreResources(base.BaseTestCase):
         for r in TestCoreResources.CORE_DEFS:
             self.assertIs(r.RESOURCE_ATTRIBUTE_MAP[r.COLLECTION_NAME],
                           attributes.RESOURCES[r.COLLECTION_NAME])
+
+
+class TestValidatePriviliges(base.BaseTestCase):
+
+    def test__validate_privileges_same_tenant(self):
+        project_id = 'fake_project'
+        ctx = context.Context(project_id=project_id)
+        res_dict = {'project_id': project_id}
+        try:
+            attributes._validate_privileges(ctx, res_dict)
+        except exc.HTTPBadRequest:
+            self.fail("HTTPBadRequest exception should not be raised.")
+
+    def test__validate_privileges_user_other_tenant(self):
+        project_id = 'fake_project'
+        ctx = context.Context(project_id='fake_project2')
+        res_dict = {'project_id': project_id}
+        self.assertRaises(
+            exc.HTTPBadRequest,
+            attributes._validate_privileges,
+            ctx, res_dict)
+
+    def test__validate_privileges_admin_other_tenant(self):
+        project_id = 'fake_project'
+        ctx = context.Context(project_id='fake_project2',
+                              is_admin=True)
+        res_dict = {'project_id': project_id}
+        try:
+            attributes._validate_privileges(ctx, res_dict)
+        except exc.HTTPBadRequest:
+            self.fail("HTTPBadRequest exception should not be raised.")
+
+    def test__validate_privileges_advsvc_other_tenant(self):
+        project_id = 'fake_project'
+        ctx = context.Context(project_id='fake_project2',
+                              is_advsvc=True)
+        res_dict = {'project_id': project_id}
+        try:
+            attributes._validate_privileges(ctx, res_dict)
+        except exc.HTTPBadRequest:
+            self.fail("HTTPBadRequest exception should not be raised.")
